package CF2022;
use Mojo::Base 'Mojolicious';
use Mojo::Redis;

# This method will run once at server start
sub startup {
    my $self = shift;

    my $cfg = $self->plugin('Config' => { file => 'cf2022.conf'} );
    $self->helper( cfg => sub { return $cfg; } );

    # Konfigurace z ENV ma prednost
    KEY:
    foreach my $key ( keys %ENV ) {
        if ( $key =~ /^CFG_(.+)/i ) {
            $cfg->{lc($1)} = $ENV{$key};
        }
    }

    # Redis
#    my $redis = Mojo::Redis->new( $cfg->{redis} );
#    $self->helper( redis => sub { return $redis; } );

    $self->plugin('CF2022::Helpers::Core');
    $self->plugin('CF2022::Helpers::Auth');

    $self->plugin("OpenAPI" => {
        url    => $self->home . '/openapi.yaml',
        schema => 'v3',
        plugins                        => [qw(+SpecRenderer +Cors +Security)],
        render_specification           => 1,
        render_specification_for_paths => 1,
        default_response_codes         => [400, 401, 403, 404, 429, 500, 501],
    });

    $self->defaults(
        openapi_cors_allowed_origins => ['*']
    );

    # Router
    my $r = $self->routes;
    $r->get('/')->to(cb => sub { shift->redirect_to('/api.html');});

}

1;
